@@ -73,8 +73,8 @@ class browser:
     
     def add_and_print_log(self, message, add_log = True):
         if (add_log):
-            log = classes.soapberry_log()
+            log = soapberry.classes.soapberry_log()
             log.time = datetime.now().strftime("%d/%m/%Y %H:%M:%S")
             log.message = message
-            helpers.print_log(log)
+            soapberry.helpers.print_log(log)
             self.logs.append(log)
\ No newline at end of file
